****************************
The sherpa.astro.data module
****************************

.. currentmodule:: sherpa.astro.data

.. automodule:: sherpa.astro.data

   .. rubric:: Classes
               
   .. autosummary::
      :toctree: api

      DataPHA
      DataARF
      DataRMF
      DataIMG
      DataIMGInt
      DataRosatRMF
   
Class Inheritance Diagram
=========================

.. inheritance-diagram:: DataPHA DataARF DataRMF DataIMG DataIMGInt DataRosatRMF
   :parts: 1
